@@ -16,7 +16,6 @@
 
 package org.apache.storm.kafka;
 
-import java.util.Collections;
 import java.util.List;
 import org.apache.kafka.clients.consumer.ConsumerRecord;
 import org.apache.storm.kafka.spout.RecordTranslator;
@@ -34,9 +33,4 @@ public class NullRecordTranslator<K, V> implements RecordTranslator<K, V> {
     public Fields getFieldsFor(String stream) {
         return new Fields("topic", "key", "value");
     }
-
-    @Override
-    public List<String> streams() {
-        return Collections.singletonList("default");
-    }
 }
